==> semeio-1.5.2.tar.gz: semeio-1.5.2/semeio/workflows/spearman_correlation_job/spearman_correlation.py <==
import argparse

from ert.shared.plugins.plugin_manager import hook_implementation

from semeio.communication import SemeioScript
from semeio.workflows.correlated_observations_scaling.cos import (
    CorrelatedObservationsScalingJob,
)
from semeio.workflows.correlated_observations_scaling.exceptions import (
    EmptyDatasetException,
)
from semeio.workflows.spearman_correlation_job.job import spearman_job


class SpearmanCorrelationJob(SemeioScript):
    def run(self, *args):
        # pylint: disable=method-hidden
        # (SemeioScript wraps this run method)

        obs_keys = [
            self.facade.get_observation_key(nr)
            for nr, _ in enumerate(self.facade.get_observations())
        ]

        measured_data = self.facade.get_measured_data(obs_keys)

        parser = spearman_job_parser()
        args = parser.parse_args(args)

        scaling_configs = spearman_job(
            measured_data, self.reporter, threshold=args.threshold
        )

        if not args.dry_run:
            try:
                # pylint: disable=not-callable
                CorrelatedObservationsScalingJob(self.ert()).run(scaling_configs)
            except EmptyDatasetException:
                pass
        return self._output_dir


def spearman_job_parser():
    description = """R
    A module that calculates the Spearman correlation in simulated data
    and clusters
    """
    parser = argparse.ArgumentParser(description=description)
    parser.add_argument(
        "-t",
        "--threshold",
        required=False,
        default=1.15,
        type=float,
        help="""
        Forms flat clusters so that the original
        observations in each flat cluster have no greater a
        cophenetic distance than `t`.
        """,
    )
    parser.add_argument(
        "--output-file",
        required=False,
        type=str,
        help="Name of the outputfile. The format will be yaml.",
    )
    parser.add_argument(
        "-n",
        "--dry-run",
        required=False,
        help="Dry run, no scaling will be performed",
        action="store_true",
    )
    return parser


@hook_implementation
def legacy_ertscript_workflow(config):
    workflow = config.add_workflow(SpearmanCorrelationJob, "SPEARMAN_CORRELATION")
    workflow.parser = spearman_job_parser
    workflow.category = "observations.correlation"

==> semeio-1.6.0rc0.tar.gz: semeio-1.6.0rc0/semeio/workflows/spearman_correlation_job/spearman_correlation.py <==
import argparse

from ert.shared.plugins.plugin_manager import hook_implementation

from semeio.communication import SemeioScript
from semeio.workflows.correlated_observations_scaling.cos import (
    CorrelatedObservationsScalingJob,
)
from semeio.workflows.correlated_observations_scaling.exceptions import (
    EmptyDatasetException,
)
from semeio.workflows.spearman_correlation_job.job import spearman_job


class SpearmanCorrelationJob(SemeioScript):
    def run(self, *args):
        # pylint: disable=method-hidden
        # (SemeioScript wraps this run method)

        obs_keys = [o.getKey() for o in self.facade.get_observations()]

        measured_data = self.facade.get_measured_data(obs_keys, ensemble=self.ensemble)

        parser = spearman_job_parser()
        args = parser.parse_args(args)

        scaling_configs = spearman_job(
            measured_data, self.reporter, threshold=args.threshold
        )

        if not args.dry_run:
            try:
                # pylint: disable=not-callable
                CorrelatedObservationsScalingJob(
                    self.ert(), self.storage, ensemble=self.ensemble
                ).run(scaling_configs)
            except EmptyDatasetException:
                pass
        return self._output_dir


def spearman_job_parser():
    description = """R
    A module that calculates the Spearman correlation in simulated data
    and clusters
    """
    parser = argparse.ArgumentParser(description=description)
    parser.add_argument(
        "-t",
        "--threshold",
        required=False,
        default=1.15,
        type=float,
        help="""
        Forms flat clusters so that the original
        observations in each flat cluster have no greater a
        cophenetic distance than `t`.
        """,
    )
    parser.add_argument(
        "--output-file",
        required=False,
        type=str,
        help="Name of the outputfile. The format will be yaml.",
    )
    parser.add_argument(
        "-n",
        "--dry-run",
        required=False,
        help="Dry run, no scaling will be performed",
        action="store_true",
    )
    return parser


@hook_implementation
def legacy_ertscript_workflow(config):
    workflow = config.add_workflow(SpearmanCorrelationJob, "SPEARMAN_CORRELATION")
    workflow.parser = spearman_job_parser
    workflow.category = "observations.correlation"
